Crate kcr_networking_gke_io

Crate kcr_networking_gke_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the networking.gke.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

networking.gke.io/v1

  • ManagedCertificate
  • GCPBackendPolicy
  • GCPGatewayPolicy
  • HealthCheckPolicy
  • LBPolicy

Modules

v1